@@ -55,41 +55,48 @@ class StreamApp(object):
         return finished
 
     def loop_input_port(self):
+        print("actor_process_1>>>>>>>>>>>>>>>>>>>>>")
         if isinstance(self.actor, SourceActor):
+            print("actor_process_2>>>>>>>>>>>>>>>>>>>>>")
             for item in self.actor.__iter__():
-                self.actor_running()
+                # self.actor_running()
+                print("actor_process_3>>>>>>>>>>>>>>>>>>>>>")
                 self.actor.emit(item)
         else:
+            print("actor_process_4>>>>>>>>>>>>>>>>>>>>>")
             stream_names_input_map = {}
             upstream_actors = []
             for input_port in self.actor.get_input_ports():
                 stream_names_input_map[input_port.channel] = input_port
                 upstream_actors.append(input_port.upstream_actor)
+            print("actor_process_5>>>>>>>>>>>>>>>>>>>>>")
             consumer_id = generate()
             group_name = self.current_actor_name
+            print("actor_process_6>>>>>>>>>>>>>>>>>>>>>")
             while True:
                 consumer = RedisConsumer(self.redis_client, group_name, stream_names_input_map.keys())
                 msgs = consumer.consume(consumer_id, 1)
                 # 如果消息为空，判断上游所有算子状态是否结束
                 if len(msgs) <= 0:
                     if self.check_failed(upstream_actors):
-                        self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
-                                                              actor_constant.ACTOR_STATE_FAILED)
+                        # self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
+                        #                                       actor_constant.ACTOR_STATE_FAILED)
                         raise Exception("all upstream job failed!")
                     if self.check_finished(upstream_actors):
-                        self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
-                                                              actor_constant.ACTOR_STATE_SUCCESS)
+                        # self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
+                        #                                       actor_constant.ACTOR_STATE_SUCCESS)
                         break
-
-                self.actor_running()
+                print("actor_process_7>>>>>>>>>>>>>>>>>>>>>")
+                # self.actor_running()
                 # msgs消息格式
                 # [[b'Source&success', [(b'1652346017746-2', {b'': b'{"payload": "C1(=N/NC(COC2C(Cl)=CC(=CC=2Cl)Cl)=O)\\\\C2C=C(Br)C=C(C)C=2N(C)C\\\\1=O\\tMCULE-8250840838\\n", "flag": "0", "type": "TextOutputPort"}'})]]]
                 for msg in msgs:
-                    print("parse message")
+                    print("actor_process_8>>>>>>>>>>>>>>>>>>>>>")
                     # 解析stream_name
                     stream_name = msg[0].decode()
                     msg_items = msg[1]
                     for msg_item in msg_items:
+                        print("actor_process_9>>>>>>>>>>>>>>>>>>>>>")
                         # 解析消息ID
                         msg_id = msg_item[0]
                         # 解析消息体
@@ -100,12 +107,15 @@ class StreamApp(object):
                         # msg_object = json.loads(msg_body)
                         consumer.ack(stream_name, msg_id)
                         input_port = stream_names_input_map[stream_name]
+                        print("actor_process_10>>>>>>>>>>>>>>>>>>>>>")
                         # 获取消息payload
                         content = msg_object.get_payload()
                         if isinstance(self.actor, SinkActor):
+                            print("actor_process_11>>>>>>>>>>>>>>>>>>>>>")
                             print('-----sink算子')
                             self.actor.write(content, input_port)
                         elif isinstance(self.actor, ComputeActor) or isinstance(self.actor, ParallelComputeActor):
+                            print("actor_process_12>>>>>>>>>>>>>>>>>>>>>")
                             print('----计算算子')
                             self.actor.process(content, input_port)
                         else:
@@ -269,7 +279,7 @@ class StreamApp(object):
         self.actor.set_input_ports(input_ports)
         self.actor.set_output_ports(output_ports)
         # 设置actor状态为已开始
-        self.actor_ready()
+        # self.actor_ready()
         print("process_source_actor>>>>>start")
         self.process_actor()
         print("process_source_actor>>>>>end")
